@@ -9,9 +9,6 @@ use image::{ColorType, ImageBuffer, Rgba};
 use std::fs::File;
 use std::io::{BufWriter, Read, Write};
 
-#[cfg(not(feature = "wasm-extension"))]
-use mtpng;
-
 /// Decodes and returns a PNG.
 ///
 /// # Arguments
@@ -93,7 +90,7 @@ pub fn write_png_to_file(
 
 /// Writes a PNG to the local file system using the default
 /// compression and filter settings.
-/// 
+///
 /// Avoid the usage of external enumeration values.
 ///
 /// # Arguments
